<?php
namespace Teknisa\PLA\Modules\Cardapio\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO;

class Pla07800AcompanhamentoDeAprovacaoDeCardapio extends \Zeedhi\Framework\Controller\Report {

    protected $environment;
    protected $crudService;
    protected $reportService;
    protected $connection;
    protected $birtStrategy;
    protected $util;
    protected $dataSourceManager;

    protected $reportMapping = array(
        'PLA07800' => array(
            'strategy' => 'BIRT',
            'parameterMapping'  => array(
                'P_CDGRUPO'       => 'P_CDGRUPO',
                'L_FILIAL1'       => 'L_FILIAL1',
                'L_SERVICO1'      => 'L_SERVICO1',
                'P_DTMESAPROVINI' => 'P_DTMESAPROVINI',
                'P_DTMESAPROVFIN' => 'P_DTMESAPROVFIN',
                'LANGUAGE'        => 'P_LOGIN_LANGUAGE',
                'NRORG'           => 'P_NRORG'
            )
        )
    );

    public function __construct($reportService, $environment, $connection, $crudService, $birtStrategy, $util, $dataSourceManager) {
        $this->environment       = $environment;
        $this->connection        = $connection;
        $this->crudService       = $crudService;
        $this->reportService     = $reportService;
        $this->birtStrategy       = $birtStrategy;
        $this->util              = $util;
        $this->dataSourceManager = $dataSourceManager;

        parent::__construct($reportService);
    }

    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        if($row['L_FILIAL1'] == 'T'){
            $filiais = $this->findFilial($row);
        }else {
            $filiais = $row['L_FILIAL1'];
        }
        $row['L_FILIAL1'] = $this->util->insertLista($filiais);
        
        if($row['L_SERVICO1'] == 'T'){
            $servicos = $this->findServico($row);
        }else {
            $servicos = explode('_', $row['L_SERVICO1']);
        }
        $row['L_SERVICO1'] = $this->util->insertLista($servicos);
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
    }
    
    public function findServico($row){
        try {
            $query = "SELECT DISTINCT
                            NRORG,
                            CDFILIAL,
                            CDSERVFILI,
                            CDFILIAL||CDSERVFILI AS FILISERV
                        FROM
                            SERVICO
                        WHERE
                            VALOR_NA_LISTA(CDFILIAL, :CDFILIAL) <> 0
                        ORDER BY
                            CDFILIAL,
                            CDSERVFILI";
            
            $params = array(
                "CDFILIAL"   => "_NRLISTA=".$row['L_FILIAL1']
            );
            $dataSet = $this->connection->fetchAll($query, $params);
            $resultado = array();
            foreach($dataSet as $servico){
                $resultado[] = $servico['FILISERV'];
            }
            return $resultado;
        } catch (\Exception $e) {
            throw $e;
        }
    }
    public function findFilial($row){
        try {
            $query = "SELECT DISTINCT
                             F.NRORG,
                             F.CDFILIAL,
                             F.NMFILIAL,
                             F.IDCNTRRESC,
                             F.IDATIVO,
                             F.CDREGIAO
                        FROM
                             FILIAL        F
                             INNER JOIN FILIOPER      FO ON FO.NRORG = F.NRORG
                                                      AND FO.CDFILIAL = F.CDFILIAL
                             LEFT JOIN FILGRUPFILI   FG ON F.NRORG = FG.NRORG
                                                        AND F.CDFILIAL = FG.CDFILIAL
                        WHERE
                             F.NRORG = :NRORG
                             AND FO.CDOPERADOR = :CDOPERADOR
                             AND ( :CDGRUPFILI = FG.CDGRUPFILI
                                  OR :CDGRUPFILI = 'T' )
                        ORDER BY
                             CDFILIAL";
            $params = array(
                "CDOPERADOR" => $row['CDOPERADOR'],
                "CDGRUPFILI" => $row['P_CDGRUPO'],
                "NRORG"      => $this->environment->getNrorgTrab()
            );
            $filiais = $this->connection->fetchAll($query, $params);
            $resultado = array();
            foreach($filiais as $filial){
                $resultado[] = $filial['CDFILIAL'];
            }
            return $resultado;
        
        } catch (\Exception $e) {
            throw $e;
        }
    }
}